@@ -67,12 +67,10 @@ power.RSABE <- function(alpha=0.05, theta1, theta2, theta0, CV, n,
     # then we assume n=ntotal
     # for unbalanced designs we divide the ns by ourself
     # to have only small imbalance
-    ni <- round(n/seqs,0)
-    nv <- rep.int(ni, times=seqs-1)
-    nv <- c(nv, n-sum(nv))
-    if (nv[length(nv)]!=ni){
-      message("Unbalanced design. n(i)=", paste(nv, collapse="/"),
-              " assumed.")
+    nv <- nvec(n=n, grps=seqs)
+    #browser()
+    if (nv[1]!=nv[length(nv)]){
+      message("Unbalanced design. n(i)=", paste(nv, collapse="/"), " assumed.")
     } 
     C3 <- sum(1/nv)/seqs^2
     n  <- sum(nv)
